﻿(function () {

    "use strict";

    angular.module("enrDetailsPaneModule")
           .directive("detailsContactInfo", [function () {
               return {
                   templateUrl: "Scripts/EnrAngular/EnrDetailsPane/detailsContactInfo.html",
                   controller: "detailsContactInfoController",
                   scope: {},
                   restrict: "E"
               };
           }])
           .controller("detailsContactInfoController", ["$scope", "enrModeManager", "detailsViewModeManager", "detailsData", "detailsAddressInjector", "mapSelectedRegion", "officeJsonRegionFilter", "primaryService", "participationCalculator", function ($scope, enrModeManager, detailsViewModeManager, detailsData, detailsAddressInjector, mapSelectedRegion, officeJsonRegionFilter, primaryService, participationCalculator) {
               var navBarClass = "navbar navbar-default";
               $scope.isShowRef = false;
               $scope.isGeneralRef = false;                       
               $scope.titleVisibility = "";
               $scope.noResultsForReferendums = "hidden";
               $scope.numberOfSeats = '';

               // Details View Mode (Summary, County, etc...)
               $scope.navItemClicked = function (index) {
                   var newMode = index === 0 ? detailsViewModeManager.modeEnum.summary : detailsViewModeManager.modeEnum.county;                   
                   detailsViewModeManager.setCurMode(newMode);
                   hideTitle(newMode);
               }            
               $scope.$on(detailsViewModeManager.modeChangeEventName, function (event, newMode) {
                   $scope.summaryItemClass = "nav";
                   $scope.countyItemClass = "nav";

                   if (newMode === detailsViewModeManager.modeEnum.summary)
                       $scope.summaryItemClass += " active";
                   else
                       $scope.countyItemClass += " active";

                   hideTitle(newMode);
               });

               $scope.$on("SLICK_OFFICE_SELECTION", function () {
                   detailsViewModeManager.setCurMode(detailsViewModeManager.modeEnum.summary);
                   hideTitle(detailsViewModeManager.modeEnum.summary);
               });             

               $scope.$on(enrModeManager.modeChangeEventName, function (event, newMode) {
                   if (newMode === enrModeManager.modeEnum.offices) {
                       detailsViewModeManager.setCurMode(detailsViewModeManager.modeEnum.summary);
                       $scope.isShowRef = false;
                       hideTitle(newMode);
                   }
               });

               $scope.$on("SELECTED_PARTY_CHANGED", function () {
                   detailsViewModeManager.setCurMode(detailsViewModeManager.modeEnum.summary);
                   hideTitle(detailsViewModeManager.modeEnum.summary);
               });

               $scope.$on("OFFICE_CHANGED", function () {
                   detailsViewModeManager.setCurMode(detailsViewModeManager.modeEnum.summary);
               });               

               detailsViewModeManager.setCurMode(detailsViewModeManager.modeEnum.summary);

               
               function hideTitle(newMode) {
                   if (enrModeManager.isOfficeMode() && newMode == detailsViewModeManager.modeEnum.county) {
                       $scope.titleVisibility = "hidden";
                       $scope.numberOfSeats = '';
                   }
                   else {
                       $scope.titleVisibility = "";
                   }

                   if (enrModeManager.isOfficeMode()) {
                       $scope.noResultsForReferendums = "hidden";
                   }
               }

               // Data Population
               var refreshDataBindingsOfficeMode = function () {
                   $scope.contactTitle = detailsData.getData().OfficeCategory.OFFICE_CATEGORY_NAME;                  
                   if (mapSelectedRegion.isAnyRegionSelected()) {
                       $scope.navBarClass = navBarClass + " hidden";
                       var regionData = officeJsonRegionFilter.getRegionNodes(detailsData.getData(), mapSelectedRegion.getSelectedRegionProperties())[0];

                       if (regionData !== undefined && regionData !== null) {
                           var isCounty = isNaN(regionData.MAP_JURISDICTION_NAME);
                           if (isCounty) {
                               $scope.contactRegion = regionData.MAP_JURISDICTION_NAME.toUpperCase() + " COUNTY";

                               //Display Number of seats
                               var numberOfSeats = regionData.RegionSummary.Race.NumofSeats;                               
                               if (parseInt(numberOfSeats) > 1) {
                                   $scope.numberOfSeats = '(' + numberOfSeats + ' to be elected)';
                               }
                               else {
                                   $scope.numberOfSeats = '';
                               }
                           }
                           else
                               $scope.contactRegion = "DISTRICT " + regionData.MAP_JURISDICTION_NAME;

                           var addressInfoPresent = regionData.Office_Info !== undefined && regionData.Office_Info !== null;
                           if (addressInfoPresent) {
                               $scope.addressVisibility = "";
                               detailsAddressInjector.injectAddressInfo($scope, regionData.Office_Info);
                           } else
                               $scope.addressVisibility = "hidden";
                       } else {
                           $scope.contactRegion = "INDIANA STATE";
                           $scope.addressVisibility = "hidden";
                           $scope.numberOfSeats = '';
                       }
                   }
                   else {
                       $scope.navBarClass = navBarClass;
                       $scope.contactRegion = "INDIANA STATE";
                       $scope.addressVisibility = "hidden";
                       $scope.numberOfSeats = '';
                   }
                 
               }
               var determineNoResultsVisibilityForReferendums = function () {
                   var isVisible = false;
                   if (enrModeManager.isReferendumsMode())
                       isVisible = !participationCalculator.isReferendumsRegionParticipatingFromDetailedJson(detailsData.getRefData());
                   else if (enrModeManager.isOfficeMode())
                       isVisible = false;


                   return isVisible ? "" : "hidden";
               };

               var refreshDataBindingsReferendumsMode = function () {
                   $scope.contactTitle = "Referendums";
                   $scope.navBarClass = navBarClass + " hidden";
                   $scope.isShowRef = false;
                   $scope.numberOfSeats = '';
                   $scope.noResultsForReferendums = "hidden";

                   if (mapSelectedRegion.isAnyRegionSelected()) {
                       if (detailsData.isDataPresent()) {
                           if (detailsData.getData().Region) {
                               $scope.contactRegion = detailsData.getData().Region.JURISDICTION_NAME.toUpperCase() + " COUNTY";
                               $scope.addressVisibility = "";
                               detailsAddressInjector.injectAddressInfo($scope, detailsData.getData().Region.Office_Info);
                           }
                       }

                       if (primaryService.getIsPrimary()) {
                           $scope.noResultsForReferendums = determineNoResultsVisibilityForReferendums();
                       }
                   }
                   else {                       
                       if (primaryService.getIsPrimary()) {
                           $scope.contactRegion = "Please select a county to view results of any local public question."; //"Select a County.";
                           $scope.addressVisibility = "hidden";
                       }
                       else {
                           $scope.isGeneralRef = false;
                           if (primaryService.isStateConReferendumExist()) {
                               $scope.contactRegion = "";
                               $scope.addressVisibility = "hidden";
                               $scope.isShowRef = true;
                               $scope.referendum = primaryService.getStateConReferendum();
                           }
                           else {
                               $scope.isGeneralRef = true;
                               $scope.contactRegion = "There is no Statewide Constitutional Amendment in this election. Please select a county.";
                               $scope.addressVisibility = "hidden";
                           }
                       }
                   }                   
               }
               var refreshDataBindings = function () {
                   if (enrModeManager.isOfficeMode())
                       refreshDataBindingsOfficeMode();
                   else if (enrModeManager.isReferendumsMode())
                       refreshDataBindingsReferendumsMode();
               }
               $scope.$on(mapSelectedRegion.regionChangeEventName, function () {
                   refreshDataBindings();
                   if (enrModeManager.isOfficeMode())
                       $scope.titleVisibility = "";               
               });
               $scope.$on(detailsData.dataChangedEventName, function () {
                   refreshDataBindings();
               });

               $scope.$on("STATE_CON_REFERENDUM", function () {
                   refreshDataBindingsReferendumsMode();
               });
           }]);

}());
